package com.qmth.themis.backend.api;

import javax.annotation.Resource;

import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.qmth.themis.business.service.TEOpenService;
import com.qmth.themis.business.util.RedisUtil;
import com.qmth.themis.common.exception.BusinessException;
import com.qmth.themis.common.util.Result;
import com.qmth.themis.common.util.ResultUtil;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

/**开放接口
 * @Description: 
 * @Author: xiatian
 * @Date: 2020-10-19
 */
@Api(tags = "开放接口")
@RestController
@RequestMapping("/${prefix.url.open}")
public class TEOpenController {

    @Resource
    private TEOpenService openService;

    @Resource
    RedisUtil redisUtil;


    @ApiOperation(value = "获取考试详情")
    @RequestMapping(value = "/exam/query", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "结果信息")})
    public Result examQueryPage(@ApiParam(value = "考试id", required = false) @RequestParam(required = false) Long examId,
                                     @ApiParam(value = "考试code", required = false) @RequestParam(required = false) String code,
                                     @ApiParam(value = "分页页码", required = true) @RequestParam int pageNumber,
                                     @ApiParam(value = "分页数", required = true) @RequestParam int pageSize) {
    	if(pageSize>20) {
    		throw new BusinessException("每页最大条数为20");
    	}
        return ResultUtil.ok(openService.examQueryPage(examId, code, pageNumber, pageSize));
    }
    
    @ApiOperation(value = "获取考试课程详情")
    @RequestMapping(value = "/exam/course/query", method = RequestMethod.POST)
    @ApiResponses({@ApiResponse(code = 200, message = "结果信息")})
    public Result examCourseQueryPage(@ApiParam(value = "考试id", required = true) @RequestParam Long examId,
                                     @ApiParam(value = "课程code", required = false) @RequestParam(required = false) String courseCode,
                                     @ApiParam(value = "是否有试卷", required = false) @RequestParam(required = false) Boolean hasPaper,
                                     @ApiParam(value = "分页页码", required = true) @RequestParam int pageNumber,
                                     @ApiParam(value = "分页数", required = true) @RequestParam int pageSize) {
    	if(pageSize>100) {
    		throw new BusinessException("每页最大条数为100");
    	}
    	if(examId==null) {
    		throw new BusinessException("考试id不能为空");
    	}
        return ResultUtil.ok(openService.examCourseQueryPage(examId, courseCode,hasPaper, pageNumber, pageSize));
    }

}
